==> filer-tools-1.0.10.tgz: package/app.js <==
#!/usr/bin/env node
var util = require('util');
var exec = require('child_process').exec;
var fs = require('fs');
var path = require('path');
var touch = require('touch');


var args = process.argv.slice(2);

switch (args[0]) {
  case 'search':
    if (args[1]) {
      var keyword = args[1];
      search(keyword, process.cwd());
      break;
    } else {
      console.log("Please enter a search term.");
      break;
    }
  case 'open':
    if (args[1]) {
      var file = args[1];
      open(file);
      break;
    } else {
      console.log("Please specify a file to open.");
      break;
    }
  case 'new':
    if (args[1] && args[2]) {
      var option = args[1];
      var name = args[2];
      newFile(name, option);
      break;
    } else {
      console.log("Please enter a name.");
      break;
    }
  case 'list':
    list();
    break;
  case 'help':
    console.log("Usage:");
    console.log("filer search <keyword>           // Searches current directory and all subdirectories for a file and then opens it");
    console.log("filer open <file>                // Opens a file or folder in the current directory");
    console.log("filer new [file | folder] <name> // Creates a new file or folder in the current directory");
    console.log("filer list                       // Lists all files and folders in the current directory");
    break;
  default:
    console.log("Usage:");
    console.log("filer search <keyword>");
    console.log("filer open <file>");
    console.log("filer new [file | folder] <name>");
    console.log("filer list");
}

// Search function
function search(keyword, folder) {
  if (os == 'start') {
    searchWindows(keyword, folder);
  } else if (os == 'open') {
    searchOther(keyword, folder);
  } else if (os == 'xdg-open') {
    searchOther(keyword, folder);
  }
}

// Open function
function open(file) {
  exec(getCmd() + ' ' + file);
}

// New file function
function newFile(name, option) {
  var path = process.cwd() + '/' + name
  if (option == "file") {
    touch(path, function() {
      console.log(name + " created.");
    });
  } else if (option == "folder") {
    fs.mkdir(path, function() {
      console.log(name + " created.");
    });
  } else {
    console.log("Usage:");
    console.log("filer new file <name>");
    console.log("filer new folder <name>");
  }
}

// List function
function list() {
  fs.readdir(process.cwd(), function(err, files) {
    if (err) throw err;
    files.sort(function(a, b) {
      var aIsDir = fs.statSync(process.cwd() + "/" + a).isDirectory();
      var bIsDir = fs.statSync(process.cwd() + "/" + b).isDirectory();
      if (aIsDir && !bIsDir) return -1;
      if (!aIsDir && bIsDir) return 1;
      return a.localeCompare(b);
    });
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var stats = fs.statSync(file);
      if (stats.isDirectory()) {
        console.log("[dir ] " + file);
      } else if (stats.isFile()) {
        console.log("[file] " + file);
      }
    }
  });
}

// Helper functions
function getCmd() {
  switch (process.platform) {
    case 'darwin': return 'open';
    case 'win32': return 'start';
    case 'win64': return 'start';
    default: return 'xdg-open';
  }
}

function openExplorer(file) {
  var os = getCmd();
  if (os == 'start') {
    exec('explorer.exe /select,"' + file + '"');
  } else if (os == 'open') {
    exec('open ' + file);
  } else if (os == 'xdg-open') {
    exec('xdg-open ' + file);
  }
}

function searchWindows(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '\\' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          searchWindows(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}

function searchOther(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '/' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          searchOther(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}

==> filer-tools-1.0.12.tgz: package/app.js <==
#!/usr/bin/env node
var util = require('util');
var exec = require('child_process').exec;
var fs = require('fs');
var path = require('path');
var touch = require('touch');
var confirm = require('confirm-cli');
var rmdir = require('rmdir-recursive');

// Detect argument run appropriate command
var args = process.argv.slice(2);
switch (args[0]) {
  case 'search':
    if (args[1]) {
      var keyword = args[1];
      search(keyword, process.cwd());
      break;
    } else {
      console.log("Please enter a search term.");
      break;
    }
  case 'open':
    if (args[1]) {
      var file = args[1];
      open(file);
      break;
    } else {
      console.log("Please specify a file to open.");
      break;
    }
  case 'new':
    if (args.length > 2 && (args[2] == "file" || "folder")) {
      var option = args[1];
      for (var i = 2; i < args.length; i++) {
        var name = args[i]
        newFile(name, option);
      }
      break;
    } else {
      console.log("Please enter a name.");
      break;
    }
  case 'rename':
    if (args[1] && args[2]) {
      var oldName = args[1];
      var newName = args[2];
      rename(oldName, newName);
      break;
    } else {
      console.log("Please enter the old name and the new name.");
      break;
    }
  case 'delete':
    if (args.length > 1) {
      confirm("Are you sure you want to delete the following file(s)/folder(s)? If it is a folder, everything inside the folder will be deleted as well.",
      function() {
        for (var i = 1; i < args.length; i++) {
          var file = args[i];
          deleteFile(file);
        }
      }, function() {
        console.log("Deletion cancelled.");
      });
      break;
    } else {
      console.log("Please enter a file name to delete.");
      break;
    }
  case 'list':
    list();
    break;
  case 'help':
    console.log("Usage:");
    console.log("filer search <keyword>                         // Searches current directory and all subdirectories for a file and then opens that file");
    console.log("filer open <file>                              // Opens a file or folder");
    console.log("filer new [file | folder] <name1> <name2> ...  // Creates new file(s) or folder(s) in the current directory");
    console.log("filer rename <old> <new>                       // Renames a file");
    console.log("filer delete <file1> <file2> ...               // Deletes files specified");
    console.log("filer list                                     // Lists all files and folders in the current directory");
    break;
  default:
    console.log("Usage:");
    console.log("filer search <keyword>");
    console.log("filer open <file>");
    console.log("filer new [file | folder] <name>");
    console.log("filer rename <old> <new>");
    console.log("filer delete <file1> <file2> ...");
    console.log("filer list");
}

// Search function
function search(keyword, folder) {
  var os = getCmd();
  if (os == 'start') {
    searchWindows(keyword, folder);
  } else if (os == 'open') {
    searchOther(keyword, folder);
  } else if (os == 'xdg-open') {
    searchOther(keyword, folder);
  }
}

// Open function
function open(file) {
  exec(getCmd() + ' ' + file);
}

// New file function
function newFile(name, option) {
  var path = process.cwd() + '/' + name
  if (option == "file") {
    touch(path, function() {
      console.log(name + " created.");
    });
  } else if (option == "folder") {
    fs.mkdir(path, function() {
      console.log(name + " created.");
    });
  } else {
    console.log("Usage:");
    console.log("filer new file <name>");
    console.log("filer new folder <name>");
  }
}

// Rename function
function rename(oldName, newName) {
  fs.rename(oldName, newName, function() {
    console.log(oldName + " renamed to " + newName);
  });
}

// Delete function
function deleteFile(file) {
  fs.stat(file, function (err, stats) {
    if (err) throw err;
    if (stats.isDirectory) {
      rmdir(file, function (err) {
        if (err) throw err;
        console.log(file + " deleted");
      })
    } else {
      fs.unlink(file, function () {
        console.log(file + " deleted.");
      });
    }
  });
}

// List function
function list() {
  fs.readdir(process.cwd(), function(err, files) {
    if (err) throw err;
    files.sort(function(a, b) {
      var aIsDir = fs.statSync(process.cwd() + "/" + a).isDirectory();
      var bIsDir = fs.statSync(process.cwd() + "/" + b).isDirectory();
      if (aIsDir && !bIsDir) return -1;
      if (!aIsDir && bIsDir) return 1;
      return a.localeCompare(b);
    });
    for (var i = 0; i < files.length; i++) {
      var file = files[i];
      var stats = fs.statSync(file);
      if (stats.isDirectory()) {
        console.log("[D] " + file);
      } else if (stats.isFile()) {
        console.log("[f] " + file);
      }
    }
  });
}

// Helper functions, aka functions that the main functions call
function getCmd() {
  switch (process.platform) {
    case 'darwin': return 'open';
    case 'win32': return 'start';
    case 'win64': return 'start';
    default: return 'xdg-open';
  }
}

function openExplorer(file) {
  var os = getCmd();
  if (os == 'start') {
    exec('explorer.exe /select,"' + file + '"');
  } else if (os == 'open') {
    exec('open ' + file);
  } else if (os == 'xdg-open') {
    exec('xdg-open ' + file);
  }
}

function searchWindows(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '\\' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          searchWindows(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}

function searchOther(keyword, folder) {
  fs.readdir(folder, function(err, files) {
    for (var i = 0; i < files.length; i++) {
      var path = folder + '/' + files[i];
      var stats = fs.statSync(path);
      if (stats.isDirectory()) {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        } else {
          searchOther(keyword, path);
        }
      } else {
        if (files[i].endsWith(keyword)) {
          console.log("Opening " + keyword);
          openExplorer(path);
        }
      }
    }
  });
}
